@@ -1,5 +1,6 @@
 pub static STACK_UNDERFLOW_ERROR: &str = "Error: Stack underflow!";
 pub static INVALID_TYPE_ERROR: &str = "Error: Invalid type!";
 pub static UNKNOWN_WORD_ERROR: &str = "Error: Unknown word: ";
-pub static VARIABLE_INDEX_OUT_OR_RANGE_ERROR: &str = "Error: Varibale index out of range!";
+pub static VARIABLE_INDEX_OUT_OR_RANGE_ERROR: &str = "Error: Variable index out of range!";
+pub static VARIABLE_NOT_DEFINED: &str = "Error: Variable not defined!";
 pub static TYPE_CONVERSION_FAILURE_ERROR: &str = "Error: Type conversion failed!";
