@@ -19,7 +19,7 @@ use self::{
     logic_ops::{and, equal, grater_than, less_than, not, not_equal, or},
     loop_ops::{again_word, bynext_word, do_word, for_word, i_word, next_word, while_word},
     math_ops::{add, divide, multiply, subtract},
-    miscellaneus_ops::{bye, input, nl, silent},
+    miscellaneus_ops::{bye, input, nl, silent, emit},
     stack_ops::{dot, drop_word, dup, peek, rot, swap_word, two_dup},
     string_ops::{
         string_concat, string_creation, string_mode_toggle, string_split, string_split_whitespace,
@@ -157,6 +157,7 @@ impl WordList for Standard {
                 ),
                 (|s| s.get_curr_word() == "bye" && s.mode_normal(), bye),
                 (|s| s.get_curr_word() == "nl" && s.mode_normal(), nl),
+                (|s| s.get_curr_word() == "emit" && s.mode_normal(), emit),
                 // Type ops
                 (|s| s.get_curr_word() == "to_int" && s.mode_normal(), to_int),
                 (
